@@ -1,7 +1,9 @@
 from __future__ import annotations
 
+import pytest
+
 import narwhals as nw
-from tests.utils import Constructor, assert_equal_data
+from tests.utils import POLARS_VERSION, Constructor, assert_equal_data
 
 data = {"foo": [1, 2, 3], "BAR": [4, 5, 6]}
 
@@ -14,9 +16,11 @@ def test_to_lowercase(constructor: Constructor) -> None:
 
 
 def test_to_lowercase_after_alias(constructor: Constructor) -> None:
+    if "polars" in str(constructor) and POLARS_VERSION < (1, 32):
+        pytest.skip(reason="https://github.com/pola-rs/polars/issues/23765")
     df = nw.from_native(constructor(data))
     result = df.select((nw.col("BAR")).alias("ALIAS_FOR_BAR").name.to_lowercase())
-    expected = {"bar": [4, 5, 6]}
+    expected = {"alias_for_bar": [4, 5, 6]}
     assert_equal_data(result, expected)
 
 
