@@ -7,7 +7,6 @@ import pandas as pd
 import pytest
 
 import narwhals as nw
-import narwhals.stable.v1 as nw_v1
 from narwhals._utils import Implementation
 from tests.utils import PANDAS_VERSION, Constructor, ConstructorEager, assert_equal_data
 
@@ -16,7 +15,6 @@ import polars as pl
 
 if TYPE_CHECKING:
     from collections.abc import Mapping
-    from types import ModuleType
 
 data: Mapping[str, Any] = {"a": [1, 2, 3], "b": [4.5, 6.7, 8.9], "z": ["x", "y", "w"]}
 TEST_EAGER_BACKENDS = [
@@ -30,16 +28,13 @@ TEST_EAGER_BACKENDS = [
 
 
 @pytest.mark.parametrize("backend", TEST_EAGER_BACKENDS)
-@pytest.mark.parametrize("nw_namespace", [nw, nw_v1])
-def test_read_csv(
-    tmpdir: pytest.TempdirFactory, backend: Implementation | str, nw_namespace: ModuleType
-) -> None:
+def test_read_csv(tmpdir: pytest.TempdirFactory, backend: Implementation | str) -> None:
     df_pl = pl.DataFrame(data)
     filepath = str(tmpdir / "file.csv")  # type: ignore[operator]
     df_pl.write_csv(filepath)
-    result = nw_namespace.read_csv(filepath, backend=backend)
+    result = nw.read_csv(filepath, backend=backend)
     assert_equal_data(result, data)
-    assert isinstance(result, nw_namespace.DataFrame)
+    assert isinstance(result, nw.DataFrame)
 
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
@@ -51,10 +46,7 @@ def test_read_csv_kwargs(tmpdir: pytest.TempdirFactory) -> None:
     assert_equal_data(result, data)
 
 
-@pytest.mark.parametrize("nw_namespace", [nw, nw_v1])
-def test_scan_csv(
-    tmpdir: pytest.TempdirFactory, constructor: Constructor, nw_namespace: ModuleType
-) -> None:
+def test_scan_csv(tmpdir: pytest.TempdirFactory, constructor: Constructor) -> None:
     kwargs: dict[str, Any]
     if "sqlframe" in str(constructor):
         from sqlframe.duckdb import DuckDBSession
@@ -88,11 +80,11 @@ def test_scan_csv(
     df_pl = pl.DataFrame(data)
     filepath = str(tmpdir / "file.csv")  # type: ignore[operator]
     df_pl.write_csv(filepath)
-    df = nw_namespace.from_native(constructor(data))
-    backend = nw_namespace.get_native_namespace(df)
-    result = nw_namespace.scan_csv(filepath, backend=backend, **kwargs)
+    df = nw.from_native(constructor(data))
+    backend = nw.get_native_namespace(df)
+    result = nw.scan_csv(filepath, backend=backend, **kwargs)
     assert_equal_data(result, data)
-    assert isinstance(result, nw_namespace.LazyFrame)
+    assert isinstance(result, nw.LazyFrame)
 
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
@@ -105,20 +97,17 @@ def test_scan_csv_kwargs(tmpdir: pytest.TempdirFactory) -> None:
 
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
-@pytest.mark.parametrize("nw_namespace", [nw, nw_v1])
 def test_read_parquet(
-    tmpdir: pytest.TempdirFactory,
-    constructor_eager: ConstructorEager,
-    nw_namespace: ModuleType,
+    tmpdir: pytest.TempdirFactory, constructor_eager: ConstructorEager
 ) -> None:
     df_pl = pl.DataFrame(data)
     filepath = str(tmpdir / "file.parquet")  # type: ignore[operator]
     df_pl.write_parquet(filepath)
-    df = nw_namespace.from_native(constructor_eager(data))
-    backend = nw_namespace.get_native_namespace(df)
-    result = nw_namespace.read_parquet(filepath, backend=backend)
+    df = nw.from_native(constructor_eager(data))
+    backend = nw.get_native_namespace(df)
+    result = nw.read_parquet(filepath, backend=backend)
     assert_equal_data(result, data)
-    assert isinstance(result, nw_namespace.DataFrame)
+    assert isinstance(result, nw.DataFrame)
 
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
@@ -131,10 +120,7 @@ def test_read_parquet_kwargs(tmpdir: pytest.TempdirFactory) -> None:
 
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
-@pytest.mark.parametrize("nw_namespace", [nw, nw_v1])
-def test_scan_parquet(
-    tmpdir: pytest.TempdirFactory, constructor: Constructor, nw_namespace: ModuleType
-) -> None:
+def test_scan_parquet(tmpdir: pytest.TempdirFactory, constructor: Constructor) -> None:
     kwargs: dict[str, Any]
     if "sqlframe" in str(constructor):
         from sqlframe.duckdb import DuckDBSession
@@ -167,11 +153,11 @@ def test_scan_parquet(
     df_pl = pl.DataFrame(data)
     filepath = str(tmpdir / "file.parquet")  # type: ignore[operator]
     df_pl.write_parquet(filepath)
-    df = nw_namespace.from_native(constructor(data))
-    backend = nw_namespace.get_native_namespace(df)
-    result = nw_namespace.scan_parquet(filepath, backend=backend, **kwargs)
+    df = nw.from_native(constructor(data))
+    backend = nw.get_native_namespace(df)
+    result = nw.scan_parquet(filepath, backend=backend, **kwargs)
     assert_equal_data(result, data)
-    assert isinstance(result, nw_namespace.LazyFrame)
+    assert isinstance(result, nw.LazyFrame)
 
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
@@ -185,12 +171,10 @@ def test_scan_parquet_kwargs(tmpdir: pytest.TempdirFactory) -> None:
 
 @pytest.mark.parametrize("spark_like_backend", ["pyspark", "sqlframe"])
 @pytest.mark.parametrize("scan_method", ["scan_csv", "scan_parquet"])
-@pytest.mark.parametrize("nw_namespace", [nw, nw_v1])
 def test_scan_fail_spark_like_without_session(
     tmpdir: pytest.TempdirFactory,
     spark_like_backend: str,
     scan_method: Literal["scan_csv", "scan_parquet"],
-    nw_namespace: ModuleType,
 ) -> None:
     _ = pytest.importorskip(spark_like_backend)
 
@@ -202,4 +186,4 @@ def test_scan_fail_spark_like_without_session(
         ValueError,
         match="Spark like backends require a session object to be passed in `kwargs`.",
     ):
-        getattr(nw_namespace, scan_method)("file.parquet", backend=spark_like_backend)
+        getattr(nw, scan_method)("file.parquet", backend=spark_like_backend)
