@@ -6,6 +6,7 @@ import pytest
 
 import narwhals as nw
 from narwhals._utils import Version
+from tests.utils import POLARS_VERSION
 
 if TYPE_CHECKING:
     from narwhals.typing import IntoSeries
@@ -33,7 +34,11 @@ def test_is_ordered_categorical_polars() -> None:
 
     s: IntoSeries | Any
     s = pl.Series(["a", "b"], dtype=pl.Categorical)
-    assert nw.is_ordered_categorical(nw.from_native(s, series_only=True))
+    if POLARS_VERSION < (1, 32):
+        assert nw.is_ordered_categorical(nw.from_native(s, series_only=True))
+    else:  # pragma: no cover
+        # Post 1.32 there's no physical ordering for categoricals anymore.
+        assert not nw.is_ordered_categorical(nw.from_native(s, series_only=True))
     s = pl.Series(["a", "b"], dtype=pl.Categorical(ordering="lexical"))
     assert not nw.is_ordered_categorical(nw.from_native(s, series_only=True))
     s = pl.Series(["a", "b"], dtype=pl.Enum(["a", "b"]))
